==> jc-1.4.0.tar.gz: javax/swing/border/EmptyBorder.h <==
// public class javax.swing.border.EmptyBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class a25a7c61707145e8 javax_swing_border_EmptyBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_border_EmptyBorder_H_
#define _JC_javax_swing_border_EmptyBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_border_EmptyBorder$sub_refs	_jc_javax_swing_border_EmptyBorder$sub_refs;
typedef struct _jc_javax_swing_border_EmptyBorder$sub_nonrefs	_jc_javax_swing_border_EmptyBorder$sub_nonrefs;
typedef struct _jc_javax_swing_border_EmptyBorder$refs	_jc_javax_swing_border_EmptyBorder$refs;
typedef struct _jc_javax_swing_border_EmptyBorder$nonrefs	_jc_javax_swing_border_EmptyBorder$nonrefs;
typedef struct _jc_javax_swing_border_EmptyBorder$object	_jc_javax_swing_border_EmptyBorder$object;

typedef struct _jc_javax_swing_border_EmptyBorder$fields_struct	_jc_javax_swing_border_EmptyBorder$fields_struct;
typedef const struct _jc_javax_swing_border_EmptyBorder$vmethods	_jc_javax_swing_border_EmptyBorder$vmethods;
typedef const struct _jc_javax_swing_border_EmptyBorder$vtable	_jc_javax_swing_border_EmptyBorder$vtable;
typedef const struct _jc_javax_swing_border_EmptyBorder$vtype	_jc_javax_swing_border_EmptyBorder$vtype;

// Class fields structure
struct _jc_javax_swing_border_EmptyBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_border_EmptyBorder$fields_struct _jc_javax_swing_border_EmptyBorder$class_fields;

// Constructors
extern void _jc_javax_swing_border_EmptyBorder$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, jint, jint, jint, jint);
extern void _jc_javax_swing_border_EmptyBorder$method$_init$20cee96a25a472b6(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Insets$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_EmptyBorder$method$getBorderInsets$33a58dbd3a44f22a(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *);
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_EmptyBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *);
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_EmptyBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
extern jboolean _jc_javax_swing_border_EmptyBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *);
extern void _jc_javax_swing_border_EmptyBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_EmptyBorder$method_info$getBorderInsets$33a58dbd3a44f22a;
extern _jc_method _jc_javax_swing_border_EmptyBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_border_EmptyBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_border_EmptyBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_border_EmptyBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_border_EmptyBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$33a58dbd3a44f22a)(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *);
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *);
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_border_EmptyBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_EmptyBorder$vmethods	javax_swing_border_EmptyBorder;
};

// Vtype
struct _jc_javax_swing_border_EmptyBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_border_EmptyBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_EmptyBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_border_EmptyBorder$refs {
    _jc_javax_swing_border_EmptyBorder$sub_refs	javax_swing_border_EmptyBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_EmptyBorder$sub_nonrefs {
	jint	left;
	jint	right;
	jint	top;
	jint	bottom;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_EmptyBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_EmptyBorder$sub_nonrefs	javax_swing_border_EmptyBorder;
};

// Object instance structure
struct _jc_javax_swing_border_EmptyBorder$object {
	_jc_javax_swing_border_EmptyBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_EmptyBorder$vtype	*vtype;
	_jc_javax_swing_border_EmptyBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_EmptyBorder$vtype _jc_javax_swing_border_EmptyBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_EmptyBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_EmptyBorder$class_object;

#endif	/* _JC_javax_swing_border_EmptyBorder_H_ */

==> jc-1.4.6.tar.gz: javax/swing/border/EmptyBorder.h <==
// public class javax.swing.border.EmptyBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class a25a7c61707145e8 javax_swing_border_EmptyBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_border_EmptyBorder_H_
#define _JC_javax_swing_border_EmptyBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_border_EmptyBorder$sub_refs	_jc_javax_swing_border_EmptyBorder$sub_refs;
typedef struct _jc_javax_swing_border_EmptyBorder$sub_nonrefs	_jc_javax_swing_border_EmptyBorder$sub_nonrefs;
typedef struct _jc_javax_swing_border_EmptyBorder$refs	_jc_javax_swing_border_EmptyBorder$refs;
typedef struct _jc_javax_swing_border_EmptyBorder$nonrefs	_jc_javax_swing_border_EmptyBorder$nonrefs;
typedef struct _jc_javax_swing_border_EmptyBorder$object	_jc_javax_swing_border_EmptyBorder$object;

typedef struct _jc_javax_swing_border_EmptyBorder$fields_struct	_jc_javax_swing_border_EmptyBorder$fields_struct;
typedef const struct _jc_javax_swing_border_EmptyBorder$vmethods	_jc_javax_swing_border_EmptyBorder$vmethods;
typedef const struct _jc_javax_swing_border_EmptyBorder$vtable	_jc_javax_swing_border_EmptyBorder$vtable;
typedef const struct _jc_javax_swing_border_EmptyBorder$vtype	_jc_javax_swing_border_EmptyBorder$vtype;

// Class fields structure
struct _jc_javax_swing_border_EmptyBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_border_EmptyBorder$fields_struct _jc_javax_swing_border_EmptyBorder$class_fields;

// Constructors
extern void _jc_javax_swing_border_EmptyBorder$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_border_EmptyBorder$method$_init$20cee96a25a472b6(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_EmptyBorder$method$getBorderInsets$33a58dbd3a44f22a(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_EmptyBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_EmptyBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_border_EmptyBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_border_EmptyBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_EmptyBorder$method_info$getBorderInsets$33a58dbd3a44f22a;
extern _jc_method _jc_javax_swing_border_EmptyBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_border_EmptyBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_border_EmptyBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_border_EmptyBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_border_EmptyBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$33a58dbd3a44f22a)(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_border_EmptyBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_border_EmptyBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_EmptyBorder$vmethods	javax_swing_border_EmptyBorder;
};

// Vtype
struct _jc_javax_swing_border_EmptyBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_border_EmptyBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_EmptyBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_border_EmptyBorder$refs {
    _jc_javax_swing_border_EmptyBorder$sub_refs	javax_swing_border_EmptyBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_EmptyBorder$sub_nonrefs {
	jint	left;
	jint	right;
	jint	top;
	jint	bottom;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_EmptyBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_EmptyBorder$sub_nonrefs	javax_swing_border_EmptyBorder;
};

// Object instance structure
struct _jc_javax_swing_border_EmptyBorder$object {
	_jc_javax_swing_border_EmptyBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_EmptyBorder$vtype	*vtype;
	_jc_javax_swing_border_EmptyBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_EmptyBorder$vtype _jc_javax_swing_border_EmptyBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_EmptyBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_EmptyBorder$class_object;

#endif	/* _JC_javax_swing_border_EmptyBorder_H_ */
